@@ -1,6 +1,4 @@
 package Class::Implant;
-our $VERSION = '0.02_02';
-
 # ABSTRACT: Manipulating mixin and inheritance out of packages
 
 use 5.008008;
@@ -9,11 +7,12 @@ no  strict "refs";
 use warnings;
 use Class::Inspector;
 
+our $VERSION = '0.01';
+
 sub import {
   *{(caller)[0] . "::implant"} = \&implant;
 }
 
-
 sub implant (@) {
   my $option = ( ref($_[-1]) eq "HASH" ? pop(@_) : undef );
   my @class = @_;
@@ -21,35 +20,19 @@ sub implant (@) {
   my $target = caller;
 
   if (defined($option)) {
-  # options preprocessing
-
       $target = $option->{into} if defined($option->{into});
       eval qq{ package $target; use base qw(@class); } if $option->{inherit};
-
-      if (defined($option->{spec})) {
-        for (qw(match include exclude)) {
-          $option->{$_} = undef;
-        }
-      }
-
   }
 
-
   for my $class (reverse @class) {
-
-    my @methods = @{ get_methods($class) };
-    @methods = grep /$option->{match}/, @methods if $option->{match};
-
-    for my $function (@methods) {
+    for my $function (@{ _get_methods($class) }) {
       *{ $target . "::" . $function } = \&{ $class . "::" . $function };
     }
-
   }
 
 }
 
-sub get_methods { Class::Inspector->functions(shift) }
-
+sub _get_methods { Class::Inspector->functions(shift) }
 
 1;
 
@@ -61,7 +44,7 @@ Class::Implant - Manipulating mixin and inheritance out of packages
 
 =head1 VERSION
 
-version 0.02_02
+version 0.01
 
 =head1 SYNOPSIS
 
@@ -107,16 +90,6 @@ target package for injection.
 
 give 1 or any value to mark the inheritance
 
-=head2 spec
-
-specify what methods you want to import
-
-=head2 match
-
-give a pattern to import methods which match this pattern, for example,
-
-  implant qw(Foo Bar), { match => qr{wor\w+} }
-
 =head2 include
 
 this option is not available in 0.01
@@ -125,6 +98,10 @@ this option is not available in 0.01
 
 this option is not available in 0.01
 
+=head2 EXPORT
+
+implant()
+
 =head1 AUTHOR
 
   shelling <shelling@cpan.org>
@@ -137,7 +114,3 @@ This is free software, licensed under:
 
   The MIT (X11) License
 
-=head1 EXPORT
-
-implant()
-
