@@ -1,9 +1,8 @@
 package Foo;
-our $VERSION = '0.02_02';
+our $VERSION = '0.01';
 
 
 sub hello {"hello"}
 sub world {"world"}
-sub hill  {"hill"}
 
 1;
